# Changelog

All notable changes to this project will be documented in this file.

## [0.12.0](https://github.com/s0undt3ch/refine/releases/tag/0.12.0) - 2025-04-06

### 🚀 Features

- *(config)* Replace `pydantic` with `msgspec`

### ⚙️ Miscellaneous Tasks

- *(release)* Automate the releases
- *(changelog)* Update changelog with links to tags
- *(docs)* Build documentation in the same CI job
- *(gh-actions)* Build docs and test after pre-commit completes
- *(docs)* Build and publish docs as the final step
- *(cleanup)* Fix cache keys and other minor cleanups
- *(release)* Don't echo the multiline changelog string

## [0.11.0](https://github.com/s0undt3ch/refine/releases/tag/0.11.0) - 2025-04-04

### 🚀 Features

- Improve codemod CLI handling
- *(dependencies)* Add `py-walk` as a dependency
- *(codemods)* Allow configuring `exclude` for each codemod
- *(testing)* Allow `assert_codemod` to also validate equality
- *(gitignore)* Allow respecting `.gitignore` when excluding collected files

### 🐛 Bug Fixes

- Fix logical check variable
- Make sure custom codemod paths are importable
- *(cli)* Fix help message about default config file
- *(entry-points)* Don't blowup when failing to load an entry-point
- *(project name)* Fixed references to the old project names

## [0.10.2](https://github.com/s0undt3ch/refine/releases/tag/0.10.2) - 2025-03-31

### 📚 Documentation

- Provide a full URL to the logo so it shows on PyPi

## [0.10.1](https://github.com/s0undt3ch/refine/releases/tag/0.10.1) - 2025-03-31

### 📚 Documentation

- Bring focus to the project message
- Generate the reference docs
- *(release)* Update changelog

### ⚙️ Miscellaneous Tasks

- *(pre-commit)* Make sure we don't commit a `uv.lock` file not up to date

## [0.10.0](https://github.com/s0undt3ch/refine/releases/tag/0.10.0) - 2025-03-31

### 🚀 Features

- *(release)* Rename package to avoid conflicts on PyPi

### 📚 Documentation

- Bring focus to the project message
- Generate the reference docs

### ⚙️ Miscellaneous Tasks

- *(pre-commit)* Make sure we don't commit a `uv.lock` file not up to date

## [0.9.2](https://github.com/s0undt3ch/refine/releases/tag/0.9.2) - 2025-03-31

### 💼 Other

- Update changelog for release

### ⚙️ Miscellaneous Tasks

- Address mypy complaints, again.
- *(release)* Fix dynamic release version support
- *(release)* Switch to `hatch-vcs` for the dynamic version support

## [0.9.1](https://github.com/s0undt3ch/refine/releases/tag/0.9.1) - 2025-03-30

### 🚀 Features

- Implement `get_short_description` classmethod
- Fail if no codemods are selected

### ⚙️ Miscellaneous Tasks

- Quiet down mypy
- *(release)* Add changelog file

## [0.9.0](https://github.com/s0undt3ch/refine/releases/tag/0.9.0) - 2025-03-25

### 🚀 Features

- First Release!

<!-- generated by git-cliff -->
